using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Semitransparent;
using System.IO;

namespace DemoApplication
{
    public partial class MainForm : SemitransparentForm.StForm
    {
        public MainForm()
        {
            InitializeComponent();
            this.IsMdiContainer = true;            
            this.Size = this.MaximizedBounds.Size;
            this.StartPosition = FormStartPosition.Manual;
            this.Location = new Point(0, 0);
            this.WindowState = FormWindowState.Maximized;
            this.ActiveMdiChildInTabChanged += new EventHandler(activeMdiChildInTabChanged);
            this.Shown += new EventHandler(MainForm_shown);
            this.Closing += new CancelEventHandler(MainForm_Closing);
        }

        

        void MainForm_shown(object sender, EventArgs e)
        {
            this.Visible = false;
            ImageForm imageForm = new ImageForm();
            imageForm.pictureBox.ImageLocation = Application.StartupPath + "\\Resources\\SampleImage.jpg";
            imageForm.MdiParent = this;
            imageForm.Text = "SampleImage.jpg";
            imageForm.Show();            

			this.Visible = true;
			this.Refresh();
			imageForm.Refresh();           

            colorAdjuToolStripMenuItem_Click(null, null);
            colorAdjustmentToolStripMenuItem_Click(null, null);
            penColorToolStripMenuItem_Click(null, null);

        }

        
        private void openToolStripMenuItem_Click(object sender, EventArgs e)
        {
            System.Windows.Forms.OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = "Image files (*.jpg,*.png,*.tif,*.bmp,*.gif)|*.jpg;*.png;*.tif;*.bmp;*.gif|JPG fil" +
			"es (*.jpg)|*.jpg|PNG files (*.png)|*.png|TIF files (*.tif)|*.tif|BMP files (*.bm" +
			"p)|*.bmp|GIF files (*.gif)|*.gif";
			ofd.Title = "Open image";
            if (ofd.ShowDialog() == DialogResult.OK)
            {
                ImageForm imageForm = new ImageForm();                
                imageForm.pictureBox.ImageLocation = ofd.FileName;
                imageForm.MdiParent = this;
                imageForm.Text = Path.GetFileName(ofd.FileName);
                imageForm.Show();
            }
            ofd.Dispose();
        }
        
        private void closeToolStripMenuItem_Click(object sender, EventArgs e)
        { 
            this.Close();
        }

        Brightness_Contrast bc;
        private void colorAdjuToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (bc == null || bc.IsDisposed)
            {
                bc = new Brightness_Contrast();
                bc.MdiParent = this;
                bc.Location = new Point(7, this.Bottom - bc.Height - 7);
            }
            bc.Show();
        }

        ColorForm cf;
        private void colorAdjustmentToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (cf == null || cf.IsDisposed)
            {
                cf = new ColorForm();
                cf.MdiParent = this;
                cf.Location = new Point(this.Right - cf.Width - 7, this.Top + ControlBoxHeight + 55);
            }
            cf.Show();
        }

        GammaForm gf;
        private void penColorToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (gf == null || gf.IsDisposed)
            {
                gf = new GammaForm();
                gf.MdiParent = this;
                gf.Location = new Point(this.Right - gf.Width - 7, this.Bottom - gf.Height- 7);
            }
            gf.Show();
        }

        public PictureBox GetActivePictureBox()
        {           
            SemitransparentForm.StForm stForm = this.ActiveMdiChildInTab;
            if (stForm is ImageForm)
                return ((ImageForm)stForm).pictureBox;

            return null;
        }

        private void activeMdiChildInTabChanged(object sender, EventArgs e)
        {
            PictureBox activePictureBox = GetActivePictureBox();
            foreach (SemitransparentForm.StForm st in MdiChildren)
            {
                if (st is ControlForm)
                {
                    //((ControlForm)st).ActivePictureBox = new PictureBox();
                    ((ControlForm)st).ActivePictureBox = activePictureBox;
                }
            }
        }

        private void stFormFeaturesToolStripMenuItem_Click(object sender, EventArgs e)
        {
            StForm_Features stf = new StForm_Features();
            stf.MdiParent = this;
            stf.StartPosition = FormStartPosition.CenterScreen;
            stf.Show();
        }

        private void customShapedFormToolStripMenuItem_Click(object sender, EventArgs e)
        {
            DemoApplication.CustomShaped csForm = new CustomShaped();
            csForm.MdiParent = this;
            csForm.StartPosition = FormStartPosition.CenterScreen;
            csForm.Show();
        }
       
        void MainForm_Closing(object sender, CancelEventArgs e)
        {
            CloseForm closeForm = new CloseForm();
            closeForm.StartPosition = FormStartPosition.CenterScreen;
            DialogResult d = closeForm.ShowDialog();
            if (d != DialogResult.Yes)
                e.Cancel = true;

            closeForm.Dispose();
        }

        private void saveToolStripMenuItem_Click(object sender, EventArgs e)
        {
            string imageLocation = "";
            System.Windows.Forms.SaveFileDialog sfd = new SaveFileDialog();
            sfd.Filter = "JPG fil" +
            "es (*.jpg)|*.jpg|PNG files (*.png)|*.png|TIF files (*.tif)|*.tif|BMP files (*.bm" +
            "p)|*.bmp|GIF files (*.gif)|*.gif";
            sfd.Title = "Save image";
            if (sfd.ShowDialog() == DialogResult.OK)
            {
                try
                {
                    imageLocation = sfd.FileName;
                    PictureBox activePictureBox = GetActivePictureBox();
                    if (sfd.FilterIndex == 1)
                        activePictureBox.Image.Save(imageLocation, System.Drawing.Imaging.ImageFormat.Jpeg);
                    else if (sfd.FilterIndex == 2)
                        activePictureBox.Image.Save(imageLocation, System.Drawing.Imaging.ImageFormat.Png);
                    else if (sfd.FilterIndex == 3)
                        activePictureBox.Image.Save(imageLocation, System.Drawing.Imaging.ImageFormat.Tiff);
                    else if (sfd.FilterIndex == 4)
                        activePictureBox.Image.Save(imageLocation, System.Drawing.Imaging.ImageFormat.Bmp);
                }
                catch
                {
                    MessageBox.Show("Error in Saving file");
                }
            }
            sfd.Dispose();
        }
    }
}
